package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysRealtimeNews;

public interface ISysRealtimeNewsService
{
    public SysRealtimeNews selectSysRealtimeNewsById(Long id);

    public List<SysRealtimeNews> selectSysRealtimeNewsList(SysRealtimeNews sysRealtimeNews);

    public int insertSysRealtimeNews(SysRealtimeNews sysRealtimeNews);

    public int updateSysRealtimeNews(SysRealtimeNews sysRealtimeNews);

    public int deleteSysRealtimeNewsByIds(Long[] ids);

    public int deleteSysRealtimeNewsById(Long id);

    public int updateTopStatus(Long id, String isTop);
}
